@@ -78,7 +78,7 @@
 
 enum {
 	DISPLAY_UNBORN /* Not yet started */,
-	DISPLAY_ALIVE /* Yay! we're alive (non-xdmcp) */,
+	DISPLAY_ALIVE /* Yay! we're alive (non-XDMCP) */,
 	XDMCP_PENDING /* Pending XDMCP display */,
 	XDMCP_MANAGED /* Managed XDMCP display */,
 	DISPLAY_DEAD /* Left for dead */,
@@ -136,6 +136,36 @@ enum {
 #define FIELD_SIZE 256
 #define PIPE_SIZE 4096
 
+
+/*
+ * The following section contains keys used by the gdm.conf configuration file.
+ * Options exposed in this file are Stable, and should not change in ways that
+ * are not backwards incompatible.   Note the GDM_KEY_DEFAULTWELCOME_BACKTEST
+ * to see how backwards compatibility can be handled.
+ * 
+ * Developers who add new configuration options should ensure that they do the
+ * following:
+ * 
+ * + Specify the same default in this file as in the config/gdm.conf.in file.
+ * + Update the GET_CONFIG logic in the gdm_handle_user_message() function in
+ *   daemon/gdm.c to handle the new option.
+ * + Update the SET_CONFIG logic in the gdm_handle_user_message() function in
+ *   daemon/gdm.c to handle the new option if appropriate.
+ * + The gui/gdmsetup.c program should be updated to support the new option.
+ *   If the option affects the greeter program, make sure update_greeters() is
+ *   called.  For this to work, the update_config() logic in daemon/gdm.c
+ *   should be updated to call notify_displays_*() upon noticing the
+ *   configuration change.   The gdm_reread_config() in gui/gdmlogin.c and
+ *   gui/greeter/greeter.c will also need to be updated to notice the new
+ *   configuration option.
+ * + Update the docs/C/gdm.xml file to include information about the new
+ *   option.  Include information about any other interfaces (such as 
+ *   ENVIRONMENT variables) that may affect the configuration option.
+ *
+ * Please do this work *before* submitting an enhancement request via
+ * bugzilla. 
+ */
+
 /* Configuration constants */
 #define GDM_KEY_CHOOSER "daemon/Chooser=" EXPANDED_LIBEXECDIR "/gdmchooser"
 /* This defaults to true for backward compatibility,
@@ -175,6 +205,7 @@ enum {
 #define GDM_KEY_CONSOLE_NOTIFY "daemon/ConsoleNotify=true"
 
 #define GDM_KEY_DOUBLELOGINWARNING "daemon/DoubleLoginWarning=true"
+#define GDM_KEY_ALWAYS_LOGIN_CURRENT_SESSION "daemon/AlwaysLoginCurrentSession=false"
 
 #define GDM_KEY_DISPLAY_LAST_LOGIN "daemon/DisplayLastLogin=false"
 
@@ -239,7 +270,7 @@ enum {
 #define GDM_KEY_XDMCP_PROXY_RECONNECT "xdmcp/ProxyReconnect="
 
 #define GDM_KEY_GTK_THEME "gui/GtkTheme=Default"
-#define GDM_KEY_GTKRC "gui/GtkRC="
+#define GDM_KEY_GTKRC "gui/GtkRC=" EXPANDED_DATADIR "/themes/Default/gtk-2.0/gtkrc"
 #define GDM_KEY_ICONWIDTH "gui/MaxIconWidth=128"
 #define GDM_KEY_ICONHEIGHT "gui/MaxIconHeight=128"
 
@@ -262,7 +293,9 @@ enum {
 #define GDM_KEY_CHOOSER_BUTTON "greeter/ChooserButton=true"
 #define GDM_KEY_TITLE_BAR "greeter/TitleBar=true"
 #define GDM_KEY_DEFAULT_WELCOME "greeter/DefaultWelcome=true"
+#define GDM_KEY_DEFAULT_WELCOME_BACKTEST "greeter/DefaultWelcome="
 #define GDM_KEY_DEFAULT_REMOTEWELCOME "greeter/DefaultRemoteWelcome=true"
+#define GDM_KEY_DEFAULT_REMOTEWELCOME_BACKTEST "greeter/DefaultRemoteWelcome="
 #define GDM_KEY_WELCOME "greeter/Welcome="
 #define GDM_KEY_REMOTEWELCOME "greeter/RemoteWelcome="
 #define GDM_KEY_XINERAMASCREEN "greeter/XineramaScreen=0"
@@ -312,7 +345,7 @@ enum {
 
 #define GDM_KEY_DEBUG "debug/Enable=false"
 
-#define GDM_KEY_SERVERS "servers"
+#define GDM_KEY_SECTION_SERVERS "servers"
 
 #define GDM_KEY_SHOW_GNOME_FAILSAFE "greeter/ShowGnomeFailsafeSession=true"
 #define GDM_KEY_SHOW_XTERM_FAILSAFE "greeter/ShowXtermFailsafeSession=true"
@@ -511,8 +544,8 @@ struct _GdmForwardQuery {
 #define GDM_MAX_FORWARD_QUERIES 10
 #define GDM_FORWARD_QUERY_TIMEOUT 30
 
-/* some extra xdmcp opcodes that xdm will happily ignore since they'll be
- * the wrong xdmcp version anyway */
+/* some extra XDMCP opcodes that xdm will happily ignore since they'll be
+ * the wrong XDMCP version anyway */
 #define GDM_XDMCP_PROTOCOL_VERSION 1001
 enum {
 	GDM_XDMCP_FIRST_OPCODE = 1000, /*just a marker, not an opcode */
@@ -744,7 +777,7 @@ void		gdm_final_cleanup	(void);
 #define GDM_SUP_ATTACHED_SERVERS "ATTACHED_SERVERS" /* None */
 #define GDM_SUP_CONSOLE_SERVERS  "CONSOLE_SERVERS"  /* None */
 /* ATTACHED_SERVERS: List all attached servers, useful for Linux mostly
- *   Doesn't list xdmcp and xnest non-attached servers
+ *   Doesn't list XDMCP and xnest non-attached servers
  * CONSOLE_SERVERS supported, but deprecated due to terminology
  * Supported since: 2.2.4.0
  * Note: This command used to be named CONSOLE_SERVERS, which is still recognized
@@ -804,6 +837,18 @@ void		gdm_final_cleanup	(void);
  *      200 = Too many messages
  *      999 = Unknown error
  */
+#define GDM_SUP_GET_CONFIG_FILE  "GET_CONFIG_FILE" /* None */
+/* GET_CONFIG_FILE: Get config file location being used by
+ # the daemon.
+ * Supported since: 2.8.0.2
+ * Arguments:  None
+ * Answers:
+ *   OK <full path to GDM configuration file>
+ *   ERROR <err number> <english error description>
+ *      0 = Not implemented
+ *      200 = Too many messages
+ *      999 = Unknown error
+ */
 #define GDM_SUP_UPDATE_CONFIG "UPDATE_CONFIG" /* <key> */
 /* UPDATE_CONFIG: Tell the daemon to update config of some key.  Any user
  *             can really request that values are re-read but the daemon
