@@ -1,8 +1,19 @@
 #include "config.h"
-#include <libgnome/libgnome.h>
 #include <stdio.h>
 #include <locale.h>
 #include <string.h>
+#include <stdlib.h>
+
+#define gboolean char
+#define FALSE 0
+#define TRUE 1
+
+#ifdef ENABLE_NLS
+#include <libintl.h>
+#define _(String) gettext(String)
+#else /* !ENABLE_NLS */
+#define _(String) (String)
+#endif
 
 int
 main (int argc, char *argv[])
@@ -22,6 +33,12 @@ main (int argc, char *argv[])
 		return 0;
 	}
 
+	if (getenv ("UNSAFE_TO_TRANSLATE") != NULL &&
+	    strcmp (getenv ("UNSAFE_TO_TRANSLATE"), "yes") == 0) {
+		printf ("%s\n", string);
+		return 0;
+	}
+
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	if (is_utf8)
